import json
from typing import Any

from datamodel_code_generator import DataModelType, PythonVersion
from datamodel_code_generator.format import DatetimeClassType
from datamodel_code_generator.model import get_data_model_types
from datamodel_code_generator.parser.jsonschema import JsonSchemaParser


def json_schema_to_code(function: dict[str, Any]) -> str:
    json_schema: str = json.dumps(function)

    data_model_types = get_data_model_types(
        DataModelType.PydanticV2BaseModel,
        target_python_version=PythonVersion.PY_310,
        target_datetime_class=DatetimeClassType.Datetime,
    )
    parser = JsonSchemaParser(
        json_schema,
        data_model_type=data_model_types.data_model,
        data_model_root_type=data_model_types.root_model,
        data_model_field_type=data_model_types.field_model,
        data_type_manager_type=data_model_types.data_type_manager,
        dump_resolve_reference_action=data_model_types.dump_resolve_reference_action,
    )

    return parser.parse()
