import asyncio

from llm_taxi import Message, Role
from llm_taxi.factory import llm

from function_calling.function_calling import Function, FunctionCalling


async def main():
    messages = [Message(role=Role.User, content="What is the weather in Berlin?")]
    functions = [
        Function(
            name="get_weather",
            description="Get the weather for a location",
            parameters={
                "type": "object",
                "properties": {
                    "location": {
                        "type": "string",
                        "description": "The location to get the weather for",
                    }
                },
            },
        )
    ]

    function_calling = FunctionCalling(llm=llm("openai:gpt-4o"))
    arguments = await function_calling.function_calling(
        messages=messages, functions=functions
    )
    print(arguments)


if __name__ == "__main__":
    asyncio.run(main())
